@@ -24,15 +24,15 @@
 
 using namespace MailImporter;
 
-FilterOpera::FilterOpera() :
-    Filter(i18n("Import Opera Emails"),
-           QStringLiteral("Danny Kukawka"),
-           i18n("<p><b>Opera email import filter</b></p>"
-                "<p>This filter will import mails from Opera mail folder. Use this filter "
-                "if you want to import all mails within a account in the Opera maildir.</p>"
-                "<p>Select the directory of the account (usually ~/.opera/mail/store/account*).</p>"
-                "<p><b>Note:</b> Emails will be imported into a folder named after the account "
-                "they came from, prefixed with OPERA-</p>"))
+FilterOpera::FilterOpera()
+    : Filter(i18n("Import Opera Emails"),
+             QStringLiteral("Danny Kukawka"),
+             i18n("<p><b>Opera email import filter</b></p>"
+                  "<p>This filter will import mails from Opera mail folder. Use this filter "
+                  "if you want to import all mails within a account in the Opera maildir.</p>"
+                  "<p>Select the directory of the account (usually ~/.opera/mail/store/account*).</p>"
+                  "<p><b>Note:</b> Emails will be imported into a folder named after the account "
+                  "they came from, prefixed with OPERA-</p>"))
 {
 }
 
@@ -57,7 +57,7 @@ void FilterOpera::importRecursive(const QDir &mailDir, const QString &accountNam
             QDir importDir(mailDir.path() + QDir::separator() + *filename);
             const QStringList files = importDir.entryList(QStringList(QStringLiteral("*.[mM][bB][sS]")), QDir::Files, QDir::Name);
             if (files.isEmpty()) {
-                importRecursive(importDir, accountName.isEmpty() ?  *filename : accountName);
+                importRecursive(importDir, accountName.isEmpty() ? *filename : accountName);
             } else {
                 importBox(importDir, files, accountName);
             }
@@ -65,7 +65,7 @@ void FilterOpera::importRecursive(const QDir &mailDir, const QString &accountNam
     }
 }
 
-void FilterOpera::importBox(const QDir &importDir, const QStringList &files, const QString  &accountName)
+void FilterOpera::importBox(const QDir &importDir, const QStringList &files, const QString &accountName)
 {
     int overall_status = 0;
     int totalFiles = files.count();
@@ -75,7 +75,7 @@ void FilterOpera::importBox(const QDir &importDir, const QStringList &files, con
     for (QStringList::ConstIterator mailFile = files.constBegin(); mailFile != end; ++mailFile) {
         filterInfo()->setCurrent(0);
         QFile operaArchiv(importDir.filePath(*mailFile));
-        if (! operaArchiv.open(QIODevice::ReadOnly)) {
+        if (!operaArchiv.open(QIODevice::ReadOnly)) {
             filterInfo()->alert(i18n("Unable to open %1, skipping", *mailFile));
         } else {
             filterInfo()->addInfoLogEntry(i18n("Importing emails from %1...", *mailFile));
@@ -107,26 +107,26 @@ void FilterOpera::importBox(const QDir &importDir, const QStringList &files, con
                 QByteArray separate;
 
                 if (!first_msg) {
-                    tmp.write(input, l);
+                    tmp.write(input.constData(), l);
                 }
                 l = operaArchiv.readLine(input.data(), MAX_LINE); // read the first line, prevent "From "
-                tmp.write(input, l);
+                tmp.write(input.constData(), l);
 
-                while (! operaArchiv.atEnd() && (l = operaArchiv.readLine(input.data(), MAX_LINE)) && ((separate = input.data()).left(5) != "From ")) {
+                while (!operaArchiv.atEnd() && (l = operaArchiv.readLine(input.data(), MAX_LINE)) && ((separate = input.data()).left(5) != "From ")) {
                     /** remove in KMail unneeded Flags from Opera (for example: X-Opera-Status)*/
                     if (separate.left(8) != "X-Opera-") {
-                        tmp.write(input, l);
+                        tmp.write(input.constData(), l);
                     }
                 }
                 tmp.flush();
                 first_msg = false;
 
                 importMessage(folderName, tmp.fileName(), filterInfo()->removeDupMessage());
-                int currentPercentage = (int)(((float) operaArchiv.pos() / filenameInfo.size()) * 100);
+                int currentPercentage = (int)(((float)operaArchiv.pos() / filenameInfo.size()) * 100);
                 filterInfo()->setCurrent(currentPercentage);
 
                 if (currentFile == 1) {
-                    overall_status = (int)(currentPercentage * ((float) currentFile / totalFiles));
+                    overall_status = (int)(currentPercentage * ((float)currentFile / totalFiles));
                 } else {
                     overall_status = (int)(((currentFile - 1) * (100.0 / (float)totalFiles)) + (currentPercentage * (1.0 / (float)totalFiles)));
                 }
@@ -149,7 +149,6 @@ void FilterOpera::importBox(const QDir &importDir, const QStringList &files, con
             break;
         }
     }
-
 }
 
 void FilterOpera::import()
@@ -161,7 +160,7 @@ void FilterOpera::import()
         startdir = QDir::homePath();
     }
 
-    const QString maildir = QFileDialog::getExistingDirectory(0, QString(), startdir);
+    const QString maildir = QFileDialog::getExistingDirectory(nullptr, QString(), startdir);
     if (!maildir.isEmpty()) {
         importMails(maildir);
     }
@@ -202,4 +201,3 @@ void FilterOpera::importMails(const QString &maildir)
     filterInfo()->setCurrent(100);
     filterInfo()->setOverall(100);
 }
-
